"""
contentdiff.py
Find the Jaccard index between the textual content of fixed and mobile
versions of a website.

Reads stdin looking for lines of fixed and mobile URL pairs (separated
by a space). Writes corresponding lines to stdout consisting of the
fixed URL, the mobile URL, and the Jaccard index.

Requests are done with findmobile's request.coffee, so they have
appropriate user agents and are executed in PhantomJS. The HTML content
from the loaded page is then fed into Beautiful Soup and the textual
content is extracted (after the <script> tags--which for some reason
appear in soup.get_text()--are removed).

Example usage:
    [example.txt]
    http://google.com http://m.google.com
    http://facebook.com http://m.facebook.com
    http://cnn.com http://m.cnn.com
    [EOF]
    
    $ cat example.txt | python contentdiff.py > example.txt

"""
import bs4
from findmobile.util.request import request
import string
import sys
import os

#So findmobile.util.request can use request.coffee
os.chdir('findmobile')

def main():    
    while True:
        try:
            line=raw_input()
        except EOFError:
            break
        
        fixed_url, mobile_url=line.strip().split(' ', 1)
        
        fixed_status, _, fixed_content=request('fixed', fixed_url)
        mobile_status, _, mobile_content=request('mobile', mobile_url)
        
        if fixed_status!=mobile_status!='success':
            print fixed_url, mobile_url, 'error'
            continue
        
	try:
        	fixed_soup=bs4.BeautifulSoup(fixed_content)
        	mobile_soup=bs4.BeautifulSoup(mobile_content)	
	except:
		print 'ERROR'
        
        #Fry script tags--they show up in soup.get_text()
        for s in fixed_soup.find_all('script'):
            s.decompose()
        for s in mobile_soup.find_all('script'):
            s.decompose() 
        
        #Make bag of words
        fixed_words=set()
        mobile_words=set()
        
        for line in fixed_soup.get_text().split('\n'):
            for word in line.split(' '):
                if word:
                    fixed_words.add(strip_punctuation(word).lower())
        
        for line in mobile_soup.get_text().split('\n'):
            for word in line.split(' '):
                if word:
                    mobile_words.add(strip_punctuation(word).lower())
        
        diff=jaccard(fixed_words, mobile_words)
        
        print fixed_url, mobile_url, diff
        sys.stdout.flush()
        
def strip_punctuation(s):
    #http://stackoverflow.com/a/266162
    exclude = set(string.punctuation)
    s = ''.join(ch for ch in s if ch not in exclude)
    return s

def jaccard(s1, s2):
    return 1.0*len(s1.intersection(s2))/(len(s1.union(s2))+.00000001)

if __name__=='__main__':
    main()
