"""
finddotmobi.py
Examine the existence of .mobi versions of URLs.

Reads a list of URLs (either from a file or stdin). For each URL,
replaces the TLD with ".mobi" and tries to open the URL. If the URL can
be successfully retrieved (regardless of whether what's at the URL is
related to the original site), it is marked as a success.

Results are written to stdout, and summarized at the end of the run.

"""
import argparse
import urllib2
import sys
import time

def main():
    parser=argparse.ArgumentParser(description='Examine the existence of .mobi versions of URLs.',
                                   epilog='If no file is specified, URLs will be read from stdin.')
    parser.add_argument('-f', dest='file', type=argparse.FileType('r'))
    args=parser.parse_args()
    
    urls=[]
    if args.file:
        for line in args.file:
            if line[0]=='#':
                continue
            urls.append(line.strip())
    else:
        while True:
            try:
                urls.append(raw_input())
            except EOFError:
                break
    
    start=time.time()
    
    mobi_count=0
    for url in urls:
        if 'http://' not in url:
            url='http://'+url
                
        host, tld=url.rsplit('.', 1)
        test=host+'.mobi'
        
        sys.stdout.write('%s - trying %s ... ' % (url, test))
        sys.stdout.flush()
        
        try:
            urllib2.urlopen(test).read()
            mobi_count+=1
            
            sys.stdout.write('found!')
        except:
            sys.stdout.write('not found.')
    
        print
    
    elapsed=time.time()-start
    
    print 'URLs tested:\t', len(urls)
    print '.mobi found:\t', mobi_count
    print 'Percentage:\t', str(100.0*mobi_count/len(urls))+'%'
    print 'Elapsed time:\t %ss (%sh)' % (str(int(elapsed)),
                                         str(int(1.0*elapsed/60/60)))

if __name__=='__main__':
    main()