"""
mediqaueries.py - mediaqueries processor

Looks for the presence of CSS media queries to indicate a mobile page.

Only media queries that are based on width count for mobile sites. I
believe this is the most common way of querying for mobile devices.
There are admitted flaws in this approach, but it seems mostly workable.

"""
from ..util.logger import log
from ..util.request import request
from ..util.record import record_found, record_notfound
import re
import urllib2

#Same UA as used by request.py, used when this module directly requests a page
MOBILE_UA="Mozilla/5.0 (iPhone; U; CPU iPhone OS 4_1 like Mac OS X; en-us) AppleWebKit/532.9 (KHTML, like Gecko) Version/4.0.5 Mobile/8B117 Safari/6531.22.7 (compatible; mediaqueries/1.0; +http://cs.harding.edu)"

def find(urls, found_file, notfound_file, stats_file, error_file):
    for url in urls:
        url=url.strip()
        
        log('mediaqueries find %s' % url)
        
        log('\trequesting %s' % url)
        status, url, stylesheets, content=request('desktop', url, True)
        
        if status!='success':
            log('\terror: %s %s\n' % (url, status))
            error_file.write('\terror: %s %s\n' % (url, status))
            continue
        
        found_media=False
        found_media_width=False
        
        #Look for media queries in the document
        if (re.search('<link.*media=.*>', content)
            or re.search('@media', content)):
            found_media=True
            
            #See if the media queries 
            if (re.search('<.*media="[^"]*width:.*>', content)
                or re.search('@media[^}]*width.*{', content)):
                found_media_width=True
                
        #Look for media queries in document stylesheets
        for stylesheet in stylesheets:
            if found_media_width:
                break
            
            log('\trequesting %s' % stylesheet)
            
            try:
                #Need to request with a common UA,
                #else some sites won't give it to you
                r=urllib2.Request(stylesheet)
                r.add_header('User-Agent', MOBILE_UA)
                
                data=urllib2.build_opener().open(r).read()
                
            except Exception as e:
                #If the stylesheet request fails
                log('\terror: %s - %s\n' % (stylesheet, str(e)))
                error_file.write('error: %s stylesheet: %s url: %s\n' % (str(e), stylesheet, url))
                continue
            
            #Search the stylesheet for media queries
            if re.search('@media', data):
                found_media=True
                
                #...and make see if they look for width
                if (re.search('<.*media="[^"]*width:.*>', data)
                    or re.search('@media[^}]*width.*{', data)):
                    found_media_width=True
        
        if found_media:
            if found_media_width:
                record_found(url, url, 'width', found_file, stats_file)
            else:
                record_notfound(url, 'nowidth', notfound_file, stats_file)

        else:
            record_notfound(url, 'none', notfound_file, stats_file)
