"""
confirm_diff.py

Given two URLs, checks to make sure their content is significantly
different. Accomplished by requesting several (defined in COMPARE_COPIES)
copies of the desktop page, taking the TFDA score between each of
them against another copy desktop page, computing the mean and standard
deviation of the differences, and seeing if the difference between the
desktop page and mobile page is greater than two standard deviations
above the mean.

"""
from numpy import mean, std
from logger import log
from request import request
from TFDA import TFDA

COMPARE_COPIES=7

#Not great; I know
#It fits into the processors cleanly enough
score=None
def get_last_score():
    return score

def confirm_diff(fixed_url, mobile_url,
                 fixed_content=None, mobile_content=None):
    #Request a copy of the fixed and mobile URLs
    if fixed_content==None:
        status, _, fixed_content=request('fixed', fixed_url)
        if status!='success':
            log('%s request timeout' % fixed_url)
            return False
    
    if mobile_content==None:
        status, _, mobile_content=request('mobile', mobile_url)
        if status!='success':
            log('%s request timeout' % fixed_url)
            return False
    
    #Score the difference
    global score
    score=TFDA(fixed_content, mobile_content)
    
    #If there's no difference, I guess there's no difference
    if score==0:
        return False
    
    #Request copies of the desktop page
    log('\trequesting copies... ', False)
    
    scores=[]
    for i in range(COMPARE_COPIES):
        log('%d... ' % (i+1), False)
        
        status, _, copy_content=request('fixed', fixed_url)
        if status=='success':
            #Score the difference between the original
            #desktop page and the copy
            scores.append(TFDA(fixed_content, copy_content))
        else:
            log(' TIMEOUT ', False)
    log('')
    
    #Compute the mean and standard deviation of the copy scores
    m=mean(scores)
    s=std(scores)
    
    log('\t\tmean = %f' % m)
    log('\t\tstd  = %f' % s)
    log('\t\ttfda = %f' % score)
    
    #If the score of the mobile page is two standard deviations above
    #the mean, we'll consider it a significant difference.
    if score>m+s+s:
        log('\t\tsignificant difference')
        return True
    else:
        log('\t\tinsignificant difference')
        return False