"""
request.py

Wraps request.coffee to add a Python-side timeout. Sometimes PhantomJS
needs this--for example, when an alert box appears (and for some reason,
the PhantomJS API event wasn't working for me).

We use request.coffee and PhantomJS to get a more complete request of
the page, including redirects, JavaScript executions, etc., which could
be important for mobile pages.

"""
from subprocess import Popen, PIPE
from timeout import set_timeout, TimeoutException

TIMEOUT=30

def request(useragent, url, get_stylesheets=False):
    """
    useragent: "desktop" or "mobile"
    url: the url to request
    stylesheets: whether to include a list of stylesheet URLs
    
    Returns a tuple of the final status of the request, the final url
    (after redirects, etc.), and the content of the request.
    
    """
    status, final_url, content=None, None, None
    
    process=Popen(('phantomjs', 'request.coffee', useragent, url), stdout=PIPE)
    try:   
        (status, final_url,
         stylesheets, content)=_phantom_request(process, useragent, url)
    except TimeoutException:
        status='hang'
        stylesheets=[]
        process.kill()
    
    if get_stylesheets:
        return status, final_url, stylesheets, content
    
    return status, final_url, content

@set_timeout(TIMEOUT)
def _phantom_request(process, useragent, url):
    status=process.stdout.readline().strip()
    final_url=process.stdout.readline().strip()
    stylesheets=process.stdout.readline().strip().split(',')
    content=process.stdout.read()[:-1]
    
    return status, final_url, stylesheets, content
