"""
timeout.py

Adapted from:
http://pguides.net/python-tutorial/python-timeout-a-function/

Provides a decorator, "set_timeout", that will limit the execution of a
function to a certain time (in seconds). It will throw a
TimeoutException if the time is exceeded.

"""
import signal

class TimeoutException(Exception): 
    pass 
 
def set_timeout(timeout_time):
    def timeout_function(f):
        def f2(*args):
            def timeout_handler(signum, frame):
                raise TimeoutException()
 
            old_handler = signal.signal(signal.SIGALRM, timeout_handler) 
            signal.alarm(timeout_time)
            
            try: 
                retval = f(*args)
            except TimeoutException:
                raise TimeoutException()
            finally:
                signal.signal(signal.SIGALRM, old_handler) 
                
            signal.alarm(0)
            
            return retval
            
        return f2
        
    return timeout_function
